@@ -21,13 +21,13 @@
 #include <qdict.h>
 
 #include "functions.h"
-#include "specials.h"
+#include "specialinformation.h"
 
 class FunctionsDialog : public FunctionsDialogBase
 {
   Q_OBJECT
 public:
-  FunctionsDialog(QWidget*, const QDict<QWidget>&, char* = 0, bool = true);
+  FunctionsDialog(QWidget*, const QDict<QWidget>&, bool m_useInternalParser, char* = 0, bool = true);
   ~FunctionsDialog();
   // Return current content of text box
   QString functionText() const;
@@ -47,8 +47,13 @@ private:
   QString params();
   SpecialFunction m_function;
   int m_DCOP;
+  int m_Slots;
   const QDict<QWidget> m_widgetList;
-  const QStringList m_widgetNames;
+  QStringList m_widgetNames;
+  QStringList m_widgetTypes;
+  bool m_useInternalParser;
+  QStringList m_acceptedSlots;
+  QMap<QString, QString> m_slotList;
 };  
 
 
