@@ -140,6 +140,11 @@ void MainWindow::setupEditActions()
   actionEditLower->setWhatsThis(i18n("Lowers the selected widgets"));
   actionEditLower->setEnabled(false);
 
+  actionEditFindGlobal = new KAction(i18n("Find in Form..."), CTRL + ALT + Key_F, this, SLOT(editFindGlobal()), actionCollection(), "edit_find_global");
+  actionEditFindGlobal->setToolTip(i18n("Search for a text in the whole form."));
+  actionEditFindGlobal->setWhatsThis(whatsThisFrom("Edit|Find in Form"));
+  connect(this, SIGNAL(hasActiveForm(bool)), actionEditFindGlobal, SLOT(setEnabled(bool)));
+
   actionEditAccels = new KAction(i18n("Check Accelerators"), ALT + Key_R, this, SLOT(editAccels()),
                                  actionCollection(), "edit_check_accel");
   actionEditAccels->setToolTip(i18n("Checks if the accelerators used in the form are unique"));
@@ -182,6 +187,7 @@ void MainWindow::setupEditActions()
   actionEditSelectAll->plug(menu);
   actionEditAccels->plug(menu);
   menu->insertSeparator();
+//   actionEditFindGlobal->plug(menu); //enable when implemented
   actionEditConnections->plug(menu);
   actionEditFormSettings->plug(menu);
   menu->insertSeparator();
@@ -396,24 +402,24 @@ void MainWindow::setupToolActions()
 
 void MainWindow::setupFileActions()
 {
-  KToolBar *tb = new KToolBar(this, "File");
-  tb->setFullSize(false);
+  fileTb = new KToolBar(this, "File");
+  fileTb->setFullSize(false);
 
-  QWhatsThis::add(tb, i18n("<b>The File toolbar</b>%1").arg(toolbarHelp));
-  addToolBar(tb, i18n("File"));
+  QWhatsThis::add(fileTb, i18n("<b>The File toolbar</b>%1").arg(toolbarHelp));
+  addToolBar(fileTb, i18n("File"));
   fileMenu = new QPopupMenu(this, "File");
   menuBar()->insertItem(i18n("&File"), fileMenu);
 
   KAction *a = KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
   a->setToolTip(i18n("Creates a new dialog"));
   a->setWhatsThis(whatsThisFrom("File|New"));
-  a->plug(tb);
+  a->plug(fileTb);
   a->plug(fileMenu);
 
   a = KStdAction::open(this, SLOT(fileOpen()), actionCollection());
   a->setToolTip(i18n("Opens an existing dialog"));
   a->setWhatsThis(whatsThisFrom("File|Open"));
-  a->plug(tb);
+  a->plug(fileTb);
   a->plug(fileMenu);
 
   actionRecent = KStdAction::openRecent(this,  SLOT(fileOpenRecent(const KURL&)), actionCollection());
@@ -433,7 +439,7 @@ void MainWindow::setupFileActions()
   a->setToolTip(i18n("Saves the current dialog"));
   a->setWhatsThis(whatsThisFrom("File|Save"));
   connect(this, SIGNAL(hasActiveWindow(bool)), a, SLOT(setEnabled(bool)));
-  a->plug(tb);
+  a->plug(fileTb);
   a->plug(fileMenu);
 
   a = KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
@@ -468,6 +474,7 @@ void MainWindow::setupRunActions()
   a->setToolTip(i18n("Executes dialog"));
   a->setWhatsThis(whatsThisFrom("Run|Run dialog"));
   connect(this, SIGNAL(hasActiveForm(bool)), a, SLOT(setEnabled(bool)));
+  a->plug(fileTb);
   a->plug(menu);
 }
 
@@ -668,9 +675,11 @@ FormWindow *MainWindow::openFormWindow(const QString &filename, bool validFileNa
         statusBar()->message(i18n("Loaded file '%1'").arg(filename), 3000);
       } else
       {
+ 	emit removedFormFile(ff);
+	ff->close();
+        delete ff;
         statusBar()->message(i18n("Could not load file '%1'").arg(filename), 5000);
         KMessageBox::information(this, i18n("Could not load file '%1'").arg(filename), i18n("Load File"));
-        delete ff;
       }
       return (FormWindow *) resource.widget();
     } else
@@ -1057,6 +1066,14 @@ void MainWindow::editConnections()
   statusBar()->clear();
 }
 
+void MainWindow::editFindGlobal()
+{
+  if (!formWindow())
+    return;
+  
+}
+
+
 void MainWindow::editFormSettings()
 {
   if (!formWindow())
