@@ -17,7 +17,9 @@
 #ifndef _HAVE_PARSER_H_
 #define _HAVE_PARSER_H_
 
+#include "kommander_export.h"
 #include "parsenode.h"
+
 #include <qvaluevector.h>
 #include <qstringlist.h>
 #include <qmap.h>
@@ -31,10 +33,10 @@ public:
   Parser(ParserData* data);
   Parser(ParserData* data, const QString& expr);
   // set string to parse
-  void setString(const QString& s);
+  bool setString(const QString& s);
   // set Kommander widget associated with parser
   void setWidget(KommanderWidget* w);
-  
+
   // parse generic expression
   QString expression(Parse::Mode mode = Parse::Execute);
   // execute single command; return true if ok
@@ -46,10 +48,10 @@ public:
   // return line of errorneous node
   int errorLine() const;
   // return error message
-  QString errorMessage();
-  
+  QString errorMessage() const;
+
   // check if this is a name of standard variable
-  bool isVariable(const QString& name);
+  bool isVariable(const QString& name) const;
   // set variable value
   void setVariable(const QString& name, ParseNode value);
   // unset variable
@@ -57,20 +59,23 @@ public:
   // get variable value
   ParseNode variable(const QString& name) const;
   // access associative array 
-  const QMap<QString, ParseNode>& array(const QString& name);
+  const QMap<QString, ParseNode>& array(const QString& name) const;
   // check if this is a name of an array
   bool isArray(const QString& name) const;
   // set array key
   void setArray(const QString& name, const QString& key, ParseNode value);
   // unset array key or whole array
   void unsetArray(const QString& name, const QString& key = QString::null);
-    
+  // array value 
+  ParseNode arrayValue(const QString& name, const QString& key) const;
   // get associated widget
   KommanderWidget* currentWidget() const;
 
 private:
   // parsing function - top-down approach
-  
+
+  // parse const
+  ParseNode parseConstant(Parse::Mode mode = Parse::Execute);
   // parse value (literal or variable)
   ParseNode parseValue(Parse::Mode mode = Parse::Execute);
   // parse multiplication, division and mod (x*y, x/y, x%y)
@@ -86,7 +91,7 @@ private:
   // parse string concatenation (x+y)
   ParseNode parseConcatenation(Parse::Mode mode = Parse::Execute);
   */
-    
+
   // parse comparisons (x==y, x<y, x>y, x!=y, x<>y, x<=y, x>=y
   ParseNode parseComparison(Parse::Mode mode = Parse::Execute);
   // parse boolean not (!x, not x)
@@ -97,7 +102,7 @@ private:
   ParseNode parseOr(Parse::Mode mode = Parse::Execute);
   // parse generic condition
   ParseNode parseCondition(Parse::Mode mode = Parse::Execute);
-  
+
   // parse (x) expression
   ParseNode parseParenthesis(Parse::Mode mode = Parse::Execute);
   // parse generic expression
@@ -105,23 +110,25 @@ private:
   // parse parameters
   ParseNode parseFunction(Parse::Mode mode = Parse::Execute);
   // parse widget function
-  ParseNode parseWidget(Parse::Mode mode = Parse::Execute);
-  
+  ParseNode parseWidget(Parse::Mode mode = Parse::Execute, const QString &widgetName = QString::null);
+
   // parse assignment
-  void parseAssignment(Parse::Mode mode = Parse::Execute);
+  ParseNode parseAssignment(Parse::Mode mode = Parse::Execute);
   // parse conditional
   Parse::Flow parseIf(Parse::Mode mode = Parse::Execute);
   // parse assignment
   Parse::Flow parseCommand(Parse::Mode mode = Parse::Execute);
   // parse while loop
-  void parseWhile(Parse::Mode mode = Parse::Execute);
+  Parse::Flow parseWhile(Parse::Mode mode = Parse::Execute);
   // parse for loop
-  void parseFor(Parse::Mode mode = Parse::Execute);
+  Parse::Flow parseFor(Parse::Mode mode = Parse::Execute);
   // parse foreach loop
-  void parseForeach(Parse::Mode mode = Parse::Execute);
+  Parse::Flow parseForeach(Parse::Mode mode = Parse::Execute);
+  // parse switch block
+  void parseSwitch(Parse::Mode mode = Parse::Execute);
   // parse whole block
   Parse::Flow parseBlock(Parse::Mode mode = Parse::Execute);
-  
+
   // insert next node
   void insertNode(ParseNode p, int line);
   // next item to be parsed
@@ -130,31 +137,30 @@ private:
   bool tryKeyword(Parse::Keyword k, Parse::Mode mode = Parse::Execute);
   // check if next item is a variable, if so, return its name
   bool tryVariable(Parse::Mode mode = Parse::Execute);
-    
+
   // get the name of the next node treated as variable
-  QString nextVariable();
-  // check whether name is a valid variable is global
-  bool isVariable(const QString& name) const;
-  // check whether variable/array name is global (preceeded with _)
+  QString nextVariable(Parse::Mode mode = Parse::Execute);
+  // check whether variable/array name is global (preceded with _)
   bool isGlobal(const QString& name) const;
   // check if next item is a function
   bool isFunction() const;
   // check if next item is a widget
   bool isWidget() const;
-   
+
   // reset to default state
   void reset();
   // set error state if no error was set before; err is expected symbol that wasn't found
-  void setError(Parse::Keyword err);
+  void setError(const QString& msg);
+  void setError(const QString& msg, int pos);
   // check whether parsing was successful
   bool isError() const;
-  
+
   // parsing data
   ParserData* m_data;
   // current parsing position
   uint m_start;
-  // current parser state
-  Parse::Keyword m_error;
+  // current error message
+  QString m_error;
   // in case of error, this keeps position of first error
   uint m_errorPosition;
   // parsing nodes
