@@ -21,11 +21,12 @@
 #include <qstringlist.h>
 #include <qevent.h>
 #include <qdialog.h>
+#include <qpoint.h>
 
 /* OTHER INCLUDES */
 #include <specials.h>
 #include "dialog.h"
-#include "myprocess.h"
+#include <myprocess.h>
 
 Dialog::Dialog(QWidget *a_parent, const char *a_name, bool a_modal, int a_flags)
   : QDialog(a_parent, a_name, a_modal, a_flags), KommanderWindow(this)
@@ -36,10 +37,15 @@ Dialog::Dialog(QWidget *a_parent, const char *a_name, bool a_modal, int a_flags)
   states << "destroy";
   setStates(states);
   setDisplayStates(states);
+  m_useShebang = false;
+  m_shebang = "#!/usr/bin/kmdr-executor";
+  m_firstShow = true;
 }
 
 Dialog::~Dialog()
 {
+  if (!inEditor)
+    destroy();
 }
 
 QString Dialog::currentState() const
@@ -54,12 +60,13 @@ bool Dialog::isKommanderWidget() const
 
 bool Dialog::useInternalParser() const
 {
-  return KommanderWidget::useInternalParser; 
+  return m_useInternalParser; 
 }
 
 void Dialog::setUseInternalParser(bool b) 
 {
   KommanderWidget::useInternalParser = b; 
+  m_useInternalParser = b;
 }
 
 
@@ -123,15 +130,26 @@ void Dialog::exec()
 
 void Dialog::show()
 {
-  QDialog::show();
-  if (!inEditor)
-    initialize();
+//if the dialog is embedded in a KPart, the show can be called many times.
+//to avoid re-init and sending signals we don't want, in that case call only the
+//QWidget's show method to show the widgets, but don't do any QDialog specific 
+//task
+  if (!m_firstShow) 
+  {
+    QWidget::show();
+  } else
+  {
+    QDialog::show();
+    if (!inEditor)
+      initialize();
+    m_firstShow = false;
+  }
 }
 
 void Dialog::done(int r)
 {
-  if (!inEditor)
-    destroy();
+/*  if (!inEditor)
+    destroy();*/
   QDialog::done(r);  
 }
 
@@ -141,6 +159,22 @@ void Dialog::showEvent(QShowEvent *e)
   emit widgetOpened();
 }
 
+void Dialog::keyPressEvent( QKeyEvent *e )
+{
+  if ( e->state() == 0 && e->key() == Key_Escape)
+	return;
+  else
+   QDialog::keyPressEvent(e);
+  
+}
+
+void Dialog::contextMenuEvent( QContextMenuEvent * e )
+{
+  QDialog::contextMenuEvent( e );
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 bool Dialog::isFunctionSupported(int f)
 {
   return f == DCOP::text || f == DCOP::setText;
@@ -155,9 +189,9 @@ QString Dialog::handleDCOP(int function, const QStringList& args)
       setWidgetText(args[0]);
       break;
     default:
-      break;
+      return KommanderWidget::handleDCOP(function, args);
   }
-  return QString::null;
+  return QString();
 }
 
 
