@@ -156,7 +156,7 @@ void ExecButton::showEvent(QShowEvent* e)
 
 bool ExecButton::isFunctionSupported(int f)
 {
-  return f == DCOP::text || f == DCOP::setText;
+  return f == DCOP::text || f == DCOP::setText || f == DCOP::execute;
 }
 
 QString ExecButton::handleDCOP(int function, const QStringList& args)
@@ -167,6 +167,9 @@ QString ExecButton::handleDCOP(int function, const QStringList& args)
     case DCOP::setText:
       setWidgetText(args[0]);
       break;
+    case DCOP::execute:
+      startProcess();
+      break;
     default:
       return KommanderWidget::handleDCOP(function, args);
   }
