@@ -91,10 +91,17 @@ void LineEdit::setWidgetText(const QString& a_text)
   emit widgetTextChanged(a_text);
 }
 
+void LineEdit::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 bool LineEdit::isFunctionSupported(int f)
 {
   return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection ||
-    f == DCOP::clear;
+    f == DCOP::clear || f == DCOP::setEditable;
 }
 
 QString LineEdit::handleDCOP(int function, const QStringList& args)
@@ -113,6 +120,9 @@ QString LineEdit::handleDCOP(int function, const QStringList& args)
     case DCOP::clear:
       setWidgetText("");
       break;
+    case DCOP::setEditable:
+      setReadOnly(args[0] == "false" || args[0] == "0");
+      break;
     default:
       return KommanderWidget::handleDCOP(function, args);
   }
