@@ -28,7 +28,7 @@
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
 
-#include "kommander_export.h"
+#include <kommander_export.h>
 class QShowEvent;
 
 class KOMMANDER_EXPORT LineEdit : public KLineEdit, public KommanderWidget
@@ -58,8 +58,10 @@ public slots:
 signals:
   void widgetOpened();
   void widgetTextChanged(const QString &);
+  void contextMenuRequested(int xpos, int ypos);
 protected:
-    virtual void showEvent( QShowEvent *e );
+  virtual void showEvent( QShowEvent *e );
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
 };
 
