@@ -92,9 +92,16 @@ void RadioButton::showEvent( QShowEvent *e )
     emit widgetOpened();
 }
 
+void RadioButton::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 bool RadioButton::isFunctionSupported(int f)
 {
-  return f == DCOP::text || f == DCOP::setText || f == DCOP::setChecked;
+  return f == DCOP::text || f == DCOP::setText || f == DCOP::setChecked || f == DCOP::checked;
 }
 
 QString RadioButton::handleDCOP(int function, const QStringList& args)
@@ -113,7 +120,7 @@ QString RadioButton::handleDCOP(int function, const QStringList& args)
     default:
       return KommanderWidget::handleDCOP(function, args);
   }
-  return QString::null;
+  return QString();
 }
 
 
