@@ -20,6 +20,7 @@
 /* KDE INCLUDES */
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <klocale.h>
 
 
 /* OTHER INCLUDES */
@@ -37,7 +38,7 @@ ScriptObject::ScriptObject(QWidget *a_parent, const char *a_name)
   setDisplayStates(states);
   if (KommanderWidget::inEditor)
   {
-    setPixmap(KGlobal::iconLoader()->loadIcon("exec", KIcon::NoGroup, KIcon::SizeMedium));
+    setPixmap(KGlobal::iconLoader()->loadIcon("shellscript", KIcon::NoGroup, KIcon::SizeMedium));
     setFrameStyle(QFrame::Box | QFrame::Plain);
     setLineWidth(1);
     setFixedSize(pixmap()->size());
@@ -90,11 +91,26 @@ void ScriptObject::populate()
   setAssociatedText(KommanderWidget::evalAssociatedText(populationText()));
 }
 
-void ScriptObject::executeProcess(bool blocking)
+QString ScriptObject::executeProcess(bool blocking)
 {
-  MyProcess process(this);
-  process.setBlocking(blocking);
-  process.run(evalAssociatedText());
+  int index = ( states().findIndex( currentState()) );
+  if (index == -1)
+  {
+    printError(i18n("Invalid state for associated text."));
+    return QString();
+  }
+  QString evalText = m_associatedText[index];
+
+  if ((KommanderWidget::useInternalParser && !evalText.startsWith("#!")) || evalText.startsWith("#!kommander"))
+  {
+    evalAssociatedText(evalText);
+    return global(widgetName() + "_RESULT");
+  } else
+  {
+    MyProcess process(this);
+    process.setBlocking(blocking);
+    return process.run(evalAssociatedText(evalText));
+  }
 }
 
 void ScriptObject::execute()
@@ -142,7 +158,7 @@ QString ScriptObject::handleDCOP(int function, const QStringList& args)
       break;
     case DCOP::execute:
       m_params = args;
-      executeProcess(true);
+      return executeProcess(true);
       break;
     case DCOP::item:
     {
