@@ -55,8 +55,10 @@ public slots:
   virtual void populate();
 signals:
   void widgetOpened();
+  void contextMenuRequested(int xpos, int ypos);
 protected:
   void showEvent(QShowEvent *e);
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
 };
 
