@@ -80,9 +80,16 @@ void TabWidget::showEvent(QShowEvent* e)
   emit widgetOpened();
 }
 
+void TabWidget::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 bool TabWidget::isFunctionSupported(int f)
 {
-  return f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::insertTab;
+  return f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::insertTab  ;
 }
 
 QString TabWidget::handleDCOP(int function, const QStringList& args)
