@@ -23,9 +23,9 @@
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-
+#include <kommander_export.h>
 class QShowEvent;
-class TabWidget : public QTabWidget, public KommanderWidget
+class KOMMANDER_EXPORT TabWidget : public QTabWidget, public KommanderWidget
 {
   Q_OBJECT
   
@@ -50,8 +50,10 @@ public slots:
   virtual void populate();
 signals:
   void widgetOpened();
+  void contextMenuRequested(int xpos, int ypos);
 protected:
   void showEvent(QShowEvent *e);
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
 };
 
