@@ -63,8 +63,10 @@ public slots:
 signals:
   void widgetOpened();
   void widgetTextChanged(const QString&);
+  void contextMenuRequested(int xpos, int ypos);
 protected:
   void showEvent(QShowEvent *e);
+  void contextMenuEvent( QContextMenuEvent * e );
   int itemToIndex(QListViewItem* item);
   QString itemText(QListViewItem* item) const;
   QString itemsText();
