@@ -597,11 +597,11 @@ bool DebuggerManager::setActiveLine (const QString& file, int line )
   m_currentLine = line;
 
   // No new current position
-  if(filename.isEmpty())
+  if(filename.isEmpty() || quantaApp->previewVisible())
     return true;
 
   // Find new position in editor
-  if(ViewManager::ref()->isOpened(filename) || QExtFileInfo::exists(filename, 0L))
+  if(ViewManager::ref()->isOpened(filename) || QExtFileInfo::exists(filename, true, 0L))
     quantaApp->gotoFileAndLine(filename, line, 0);
   else
   {
