@@ -27,6 +27,7 @@ namespace DOM
 }
 class Node;
 class NodeModifsSet;
+class NodeSelection;
 class NodeSelectionInd;
 class Document;
 struct DTDStruct;
@@ -85,10 +86,26 @@ public:
 	static Node* getPrevNodeNE(Node *node, Node *endNode = 0L);
 
     
+    /**
+     * Returns the first common parent to startNode and endNode that isn't inline.
+     * @param startNode Start node.
+     * @param endNode End node.
+     * @param commonParentStartChildLocation  Is the child of commonParent which is parent of startNode
+     * @param commonParentEndChildLocation Is the child of commonParent which is parent of endNode
+     * @param nodeSubtree When startNode and endNode doesn't belong to the current document tree. Pass 0 if they do.
+     * @return The first, non inline, common parent of startNode and endNode.
+     */
     static Node* DTDGetNonInlineCommonParent(Node* startNode, Node* endNode, 
                                              QValueList<int>& commonParentStartChildLocation, 
                                              QValueList<int>& commonParentEndChildLocation, Node* nodeSubtree);
 
+    /**
+     * Same as above, only that the common parent can be inline.
+     */
+    static Node* DTDGetCommonParent(Node* startNode, Node* endNode, 
+                                    QValueList<int>& commonParentStartChildLocation, 
+                                    QValueList<int>& commonParentEndChildLocation, Node* nodeSubtree);
+
 	/**
 	 * This function returns the next DOM::Node after node : the first child of
 	 * DOM::Node if available, else its next sibling if available, else the next
@@ -112,7 +129,37 @@ public:
 	 * @return Returns the previous DOM::Node of node.
 	 */
 	static DOM::Node getPrevDomNode(DOM::Node node, DOM::Node endNode = DOM::Node());
+ 
+     /**
+      * If node is not a text node or the cursor is at the end of node's tag string, this method return the next
+      * text node at offset 0, or a null pointer.
+      * This is particular useful when finding start and end nodes of a selection, because you can have a closing node
+      * as the start node, etc.
+      * @param startNode The current start node. startNode isn't changed inside the method.
+      * @param startOffset The current start offset. startOffset is changed inside the method.
+      * @return The next text node or a null pointer.
+      */
+     static Node* getCorrectStartNode(Node* startNode, int& startOffset);
     
+     /**
+      * If node is not a text node or the cursor is at the beggining of node's tag string, this method return the previous
+      * text node at offset at the end of the tag string, or a null pointer.
+      * This is particular useful when finding start and end nodes of a selection, because you can have a closing node
+      * as the start node, etc.
+      * @param endNode The current start node.
+      * @param endOffset The current start offset.
+      * @return The next text node or a null pointer.
+      */
+     static Node* getCorrectEndNode(Node* endNode, int& endOffset);
+     
+     /**
+      * Get the first child of commonParent which is parent of node
+      * @param node 
+      * @param commonParent 
+      * @return 
+      */
+     static Node* getCommonParentChild(Node* node, Node* commonParent);
+
 
 	/** ----------------------- NODE INDENTATION STUFF -------------------------------------*/
 
@@ -253,8 +300,11 @@ public:
 	 * @return Returns a pointer to the node inserted.
 	 */
 	static Node* insertNode(Node *node, Node* parentNode, Node* nextSibling,
-		NodeModifsSet *modifs/**, Node **rootNode*/, bool merge = true);
+                            NodeModifsSet *modifs/**, Node **rootNode*/, bool merge = true);
 
+    static Node* insertNode(Node *node, Node* parentNode, Node* nextSibling, NodeSelection& selection, 
+                            NodeModifsSet *modifs, bool merge = true);
+ 
 	/**
 	 * It behaves essentially like the above function except that it can "surround" a set of Nodes with the
 	 * new Node. Thus, the closing Node is created if necessary.
@@ -306,17 +356,17 @@ public:
 	 * @return Returns false if it wasn't possible to insert the tag because e.g. of an invalid parent.
 	 */
 	static bool DTDinsertNode(Node *newNode, Node *startNode, int startOffset, Node *endNode,
-		int endOffset, Document *doc, Node **cursorNode, int &cursorOffset, NodeModifsSet *modifs);
+		int endOffset, Document *doc, Node **cursorNode, long &cursorOffset, NodeModifsSet *modifs);
 
 	/**
 	 * It behaves essentially like the above function except that it will try first to remove newNode
 	 * from the area, by calling DTDExtractNode. If newNode wasn't present, it will then insert it by
 	 * calling DTDinsertNode.
 	 * This is the key function making the toolbars working.
-         * @return Returns true if a modification was done (Node inserted/removed)
+     * @return Returns true if a modification was done (Node inserted/removed)
 	 */
 	static bool DTDinsertRemoveNode(Node *newNode, Node *startNode, int startOffset, Node *endNode,
-		int endOffset, Document *doc, Node **cursorNode, int &cursorOffset, NodeModifsSet *modifs);
+		int endOffset, Document *doc, Node **cursorNode, long &cursorOffset, NodeModifsSet *modifs);
 
 	/**
 	 * Insert a node subtree in the tree. WARNING This function will log that the nodes were added.
@@ -362,8 +412,11 @@ public:
      * @param modifs The changes made are logged into modifs.
      */
     static Node* DTDInsertNodeSubtree(Node *node, NodeSelectionInd& selection, 
-                                      Node **cursorNode, int& cursorOffset, NodeModifsSet *modifs);
+                                      Node **cursorNode, long& cursorOffset, NodeModifsSet *modifs);
 	
+    static Node* DTDInsertNodeSubtree(Node* newNode, Node* parentNode, Node* nextSibling, 
+                                      NodeSelection& cursorHolder, NodeModifsSet *modifs);
+    
     /**
 	 * Create a Node of name nodeName, of type nodeType, (see tag.h) connected to the document doc,
 	 * and nextSibling as Node's next sibling.
@@ -421,7 +474,7 @@ public:
 	 */
 	static bool DTDcreateAndInsertNode(const QString &nodeName, const QString &tagString, int nodeType,
 		Document *doc, Node *startNode, int startOffset, Node *endNode, int endOffset,
-		Node **cursorNode, int &cursorOffset, NodeModifsSet *modifs);
+		Node **cursorNode, long &cursorOffset, NodeModifsSet *modifs);
 
 	/**
 	 * For internal use. From startNode to endNode, it add where possible/necessary a new Node in order
@@ -455,7 +508,14 @@ public:
 	 * It behaves essentially like the above function except that it can handle a node Subtree.
 	 * INNEFICIENT for bi
 	 */
-	static Node *duplicateNodeSubtree(Node *node);
+    static Node *duplicateNodeSubtree(Node *node, bool childAndClosingTagOnly = false);
+ 
+    /**
+     * Returns the closing tag of node or its last child or itself.
+     * @param node 
+     * @return 
+     */
+    static Node* getLastChild(Node* node);
 
 	/**
 	 * Extract a Node from the Node Tree. WARNING this will log that the Node was removed.
@@ -484,6 +544,7 @@ public:
     
     /**
      * Extract a node subtree in the tree. WARNING This function will log that the nodes were added.
+     * This funtion not only extract the start node but also will extract inline parents.
      * @param startNode The node from which we start the removal.
      * @param startOffset The offset of startNode from which we start the removal.
      * @param endNode The node from which we end the removal.
@@ -493,7 +554,7 @@ public:
      * @return Returns a pointer to the node inserted.
      */
     static Node* DTDExtractNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset, 
-                                       Node **cursorNode, int &cursorOffset, NodeModifsSet *modifs);
+                                       Node **cursorNode, long &cursorOffset, NodeModifsSet *modifs, bool extractInlineParentNodes = true);
     
     /**
      * Similar to the above function but it operates on the given node tree. See DTDGetNodeSubtree.
@@ -501,7 +562,7 @@ public:
      * @return Returns a pointer to the node inserted.
      */
     static Node* DTDExtractNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset, 
-                                       Node* nodeSubtree, NodeModifsSet* modifs);
+                                       Node* nodeSubtree, NodeModifsSet* modifs, bool extractInlineParentNodes = true);
     
     static Node* extractNodeSubtreeAux(Node* commonParentStartChild, Node* commonParentEndChild, NodeModifsSet* modifs);
     
@@ -509,20 +570,20 @@ public:
      * It behaves essentially like the above function. Provided for convenience.
      */
     static Node* DTDRemoveSelection(NodeSelectionInd& selection, 
-                                    Node **cursorNode, int& cursorOffset, NodeModifsSet *modifs);
+                                    Node **cursorNode, long& cursorOffset, NodeModifsSet *modifs, bool extractInlineParentNodes = true);
 
     /**
      * Get a node subtree from the tree. It is similar to extractNodeSubtree() 
      * but it doesn't extract anything. 
      * It's useful to get a copy of the Node subtree from a selection, for example.
+     * This funtion not only extract the start node but also will extract inline parents.
      * @param startNode The starting Node.
      * @param startOffset If firstNode is a text, specify at which offset the new start Node will be splitted.
      * @param endNode The ending Node.
      * @param endOffset If endNode is a text, specify at which offset the new end Node will be splitted.
      * @return Returns a pointer to the Node subtree.
      */
-    static Node* getNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset/*, 
-            NodeModifsSet *modifs*/);
+    static Node* getNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset, bool extractInlineParentNodes = true);
 	
     /**
 	 * An enumeration of all the possible return states of DTDExtractNode
@@ -561,20 +622,24 @@ public:
 	 * @return Returns a kafkaCommon::extractNodeStatus.
 	 */
 	static int DTDExtractNode(const QString &nodeName, Document *doc, Node *startNode,
-		int startOffset, Node *endNode, int endOffset, Node **cursorNode, int &cursorOffset,
+		int startOffset, Node *endNode, int endOffset, Node **cursorNode, long &cursorOffset,
 		NodeModifsSet *modifs);
 
 	/**
 	 * Moves a Node somewhere else.
 	 * @param nodeToMove The node to move :-)
 	 * @param newParent The new parent of nodeToMove.
-	 * @param newNextSibling The new next Sibling of nodeToMove.
+     * @param newNextSibling The new next Sibling of nodeToMove. If null, node will be appended at
+     * the child list of parentNode.
 	 * @param modifs The changes made are logged into modifs.
 	 * @param merge Specifies if it should try to merge the Node at its new location.
 	 */
 	static void moveNode(Node *nodeToMove, Node *newParent, Node *newNextSibling,
                          NodeModifsSet *modifs, bool merge = true, bool moveClosingNode = false);
 
+    static void moveNode(Node *nodeToMove, Node *newParent, Node *newNextSibling, NodeSelection& cursorHolder,
+                         NodeModifsSet *modifs, bool merge = true, bool moveClosingNode = false);
+
 	/**
 	 * Split a Text Node at offset offset. If offset or n is invalid, nothing is done.
 	 * @param n The Node to split.
@@ -583,13 +648,67 @@ public:
 	 * @return Returns if the node was splitted.
 	 */
 	static bool splitNode(Node *n, int offset, NodeModifsSet *modifs);
-    
-    static void splitStartNodeSubtree(Node* startNode, Node* commonParent, 
-                                      QValueList<int>& commonParentStartChildLocation, NodeModifsSet* modifs);
-    static void splitEndNodeSubtree(Node* endNode, Node* commonParent, 
-                                    QValueList<int>& commonParentStartChildLocation, 
-                                    QValueList<int>& commonParentEndChildLocation, 
-                                    bool subTree, NodeModifsSet* modifs);
+ 
+    /**
+     * This method takes care of spliting start and end nodes, if needed, finding the commonParent, 
+     * commonParentStartChild and commonParentEndChild and split the start and end node subtrees, 
+     * calling splitStartNodeSubtree and splitEndNodeSubtree.
+     * The following tree:
+     *  <body>
+     *      <b>                     --> commonParent
+     *          <i>                 --> commonParentStartChild
+     *              select|
+     *              here            --> startNode  
+     *          </i>
+     *          continue
+     *          <u>                 --> commonParentEndChild
+     *              stop|           --> endNode
+     *              more
+     *          </u>
+     *          text
+     *      </b>
+     *  <body>
+     * Is changed to:
+     *  <body>
+     *      <b>
+     *          <i>
+     *              select|
+     *          </i>
+     *      </b>
+     *      <b>
+     *          <i>
+     *              here
+     *          </i>
+     *          continue
+     *          <u>
+     *              stop
+     *          </u>
+     *      </b>
+     *      <b>
+     *          <u>
+     *              more
+     *          </u>
+     *          text
+     *      </b>
+     *  </body>
+     * @param startNode The node where a selection starts, for example.
+     * @param startOffset
+     * @param endNode The node where a selection ends, for example.
+     * @param endOffset
+     * @param commonParent This is the common parent between start and end node. 
+     * If 0, it tries to find the commonParent, else it uses the passed node.
+     * @param commonParentStartChildLocation The first child of commonParent which is parent of startNode is stored here.
+     * @param commonParentEndChildLocation The first child of commonParent which is parent of endNode is stored here.
+     * @param cursorNode The cursor node is stored here.
+     * @param cursorOffset The cursor offset is stored here.
+     * @param subTree The node corresponding to the start of a subtree that doesn't belong to the current document, or 0.
+     * @param modifs The changes made are logged into modifs.
+     */
+    static void splitStartAndEndNodeSubtree(Node*& startNode, int startOffset, Node*& endNode, int endOffset, Node*& commonParent, 
+                                            QValueList<int>& commonParentStartChildLocation, 
+                                            QValueList<int>& commonParentEndChildLocation, 
+                                            NodeSelection& cursorHolder, 
+                                            Node* subTree, NodeModifsSet* modifs, bool extractInlineParentNodes = true);
 
 	/**
 	 * If n and n2 are both Text or Empty Nodes, merge them into one.
@@ -600,6 +719,8 @@ public:
 	 */
 	static bool mergeNodes(Node *n, Node *n2, NodeModifsSet *modifs, bool mergeTextOnly = false);
 
+    static bool mergeNodes(Node *n, Node *n2, NodeSelection& cursorHolder, NodeModifsSet *modifs, bool mergeTextOnly = false);
+
 	/**
 	 * This function will navigate through the Nodes from startNode to endNode and
 	 * merge identical inline Nodes as well as text Nodes.
@@ -612,7 +733,7 @@ public:
 	 * </TEMPORARY>
 	 */
 	static void mergeInlineNode(Node *startNode, Node *endNode, Node **cursorNode,
-		int &cursorOffset, NodeModifsSet *modifs);
+		long &cursorOffset, NodeModifsSet *modifs);
 
 
 	/** ----------------------- NODE MODIFICATIONS -------------------------------------*/
@@ -745,7 +866,12 @@ public:
 	 */
 	static Node* hasParent(Node *node, const QString &name);
 
+    /**
+     * Tries to find the common parent to startNode and endNode, in the same conditions as above.
+     */
+    static Node* hasParent(Node* startNode, Node* endNode, const QString &name);
 
+    
 	/** ----------------- DOM::NODE TREE MODIFICATIONS --------------------*/
 
 	/**
@@ -907,6 +1033,145 @@ public:
 	 * @param indent The number of little dots per parent relationship.
 	 */
 	static void coutTree(Node *node, int indent);
+ 
+    /**
+     * Returns whether a range is surrounded by a tag.
+     * @param start_node The start of the range to be checked.
+     * @param end_node The end of the range to be checked.
+     * @param tag_name The name of the tag, e.g., "strong".
+     * @return  -1 is not inside tag_name
+     *          1 is inside tag_name
+     *          0 mixed 
+     */
+    static int isInsideTag(Node* start_node, Node* end_node, QString const& tag_name);
+    
+    static int isInsideTag(Node* start_node, Node* end_node, QString const& tag_name, 
+                           QString const& attribute_name, QString const& attribute_value);
+    
+    /**
+     * Return whether the offset is placed between two words in a text node.
+     * @pre node is a Node of type text.
+     * @pre offset >= 0
+     * @param node The text node to be checked.
+     * @param offset The position in text we want to see if it's between words.
+     * @return true if is a space between words or if it's in the limit of a word.
+     */
+    static bool isBetweenWords(Node* node, int offset);
+
+    /**
+     * Set node and offset to the beggining of the word
+     * @pre node is a text node.
+     * @pre isBetweenWords
+     * @param node The text node, which will be changed (or not) to the start of the word.
+     * @param offset The current offset of the text node which will be changed (or not) to the start of the word.
+     * @return the offset of the beggining of the word
+     */
+    static void getStartOfWord(Node*& node, int& offset);
+
+    /**
+     * Same as above, but will get the end of the word
+     */
+    static void getEndOfWord(Node*& node, int& offset);
+
+    /**
+     * Set node and offset to the beggining of the paragraph.
+     * The distinction between inline/block nodes is used here.
+     * @param node 
+     * @param offset 
+     */
+    static void getStartOfParagraph(Node*& node, int& offset);
+    
+    static void getEndOfParagraph(Node*& node, int& offset);
+    
+private:
+    /**
+     * Split the last valid start parent (commonParentStartChild) into two.
+     * This and the method above are related and are used in sequence.
+     * The following tree:
+     *  <body>
+     *      <b>                     --> commonParent
+     *          <i>                 --> commonParentStartChild
+     *              select|
+     *              here            --> startNode
+     *          </i>
+     *          continue
+     *          <u>
+     *          stop|more
+     *          </u>
+     *          text
+     *      </b>
+     *  <body>
+     * Is changed to:
+     *  <body>
+     *      <b>
+     *          <i>
+     *              select|
+     *          </i>
+     *      </b>
+     *      <b>
+     *          <i>
+     *              here
+     *          </i>
+     *          continue
+     *          <u>
+     *              stop|more
+     *          </u>
+     *          text
+     *      </b>
+     *  </body>
+     * @param startNode The node where a selection starts, for example.
+     * @param commonParent This is the common parent between start and end node.
+     * @param commonParentStartChildLocation The first child of commonParent which is parent of startNode
+     * @param modifs The changes made are logged into modifs.
+     */
+    static void splitStartNodeSubtree(Node* startNode, Node* commonParent, 
+                                      QValueList<int>& commonParentStartChildLocation, NodeModifsSet* modifs);
+    /**
+     * Split the last valid start parent (commonParentStartChild) into two.
+     * The following tree:
+     *  <body>
+     *      <b>                     --> commonParent
+     *          <i>                 --> commonParentStartChild
+     *              select|
+     *              here     
+     *          </i>
+     *          continue
+     *          <u>                 --> commonParentEndChild
+     *              stop|           --> endNode
+     *              more
+     *          </u>
+     *          text
+     *      </b>
+     *  <body>
+     * Is changed to:
+     *  <body>
+     *      <b>
+     *          <i>
+     *              select|here
+     *          </i>
+     *          continue
+     *          <u>
+     *              stop|
+     *          </u>
+     *      </b>
+     *      <b>
+     *          <u>
+     *              more
+     *          </u>
+     *          text
+     *      </b>
+     *  </body>
+     * @param endNode The node where a selection ends, for example.
+     * @param commonParent This is the common parent between start and end node.
+     * @param commonParentStartChildLocation The first child of commonParent which is parent of startNode.
+     * @param commonParentEndChildLocation The first child of commonParent which is parent of endNode.
+     * @param subTree True if we are dealing with a tree that doesn't belong to the current document.
+     * @param modifs The changes made are logged into modifs.
+     */
+    static void splitEndNodeSubtree(Node* endNode, Node* commonParent, 
+                                    QValueList<int>& commonParentStartChildLocation, 
+                                    QValueList<int>& commonParentEndChildLocation, 
+                                    bool subTree, NodeModifsSet* modifs);
 };
 
 #endif
